/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.mail.model;

import com.liferay.portal.kernel.annotation.AutoEscape;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.model.BaseModel;
import com.liferay.portal.service.ServiceContext;

import com.liferay.portlet.expando.model.ExpandoBridge;

import java.io.Serializable;

import java.util.Date;

/**
 * The base model interface for the Account service. Represents a row in the &quot;Mail_Account&quot; database table, with each column mapped to a property of this class.
 *
 * <p>
 * This interface and its corresponding implementation {@link com.liferay.mail.model.impl.AccountModelImpl} exist only as a container for the default property accessors generated by ServiceBuilder. All helper methods and application logic should be put in {@link com.liferay.mail.model.impl.AccountImpl}.
 * </p>
 *
 * <p>
 * Never reference this interface directly. All methods that expect a account model instance should use the {@link Account} interface instead.
 * </p>
 *
 * @author    Brian Wing Shun Chan
 * @see       Account
 * @see       com.liferay.mail.model.impl.AccountImpl
 * @see       com.liferay.mail.model.impl.AccountModelImpl
 * @generated
 */
public interface AccountModel extends BaseModel<Account> {
	/**
	 * Gets the primary key of this account.
	 *
	 * @return the primary key of this account
	 */
	public long getPrimaryKey();

	/**
	 * Sets the primary key of this account
	 *
	 * @param pk the primary key of this account
	 */
	public void setPrimaryKey(long pk);

	/**
	 * Gets the account id of this account.
	 *
	 * @return the account id of this account
	 */
	public long getAccountId();

	/**
	 * Sets the account id of this account.
	 *
	 * @param accountId the account id of this account
	 */
	public void setAccountId(long accountId);

	/**
	 * Gets the company id of this account.
	 *
	 * @return the company id of this account
	 */
	public long getCompanyId();

	/**
	 * Sets the company id of this account.
	 *
	 * @param companyId the company id of this account
	 */
	public void setCompanyId(long companyId);

	/**
	 * Gets the user id of this account.
	 *
	 * @return the user id of this account
	 */
	public long getUserId();

	/**
	 * Sets the user id of this account.
	 *
	 * @param userId the user id of this account
	 */
	public void setUserId(long userId);

	/**
	 * Gets the user uuid of this account.
	 *
	 * @return the user uuid of this account
	 * @throws SystemException if a system exception occurred
	 */
	public String getUserUuid() throws SystemException;

	/**
	 * Sets the user uuid of this account.
	 *
	 * @param userUuid the user uuid of this account
	 */
	public void setUserUuid(String userUuid);

	/**
	 * Gets the user name of this account.
	 *
	 * @return the user name of this account
	 */
	@AutoEscape
	public String getUserName();

	/**
	 * Sets the user name of this account.
	 *
	 * @param userName the user name of this account
	 */
	public void setUserName(String userName);

	/**
	 * Gets the create date of this account.
	 *
	 * @return the create date of this account
	 */
	public Date getCreateDate();

	/**
	 * Sets the create date of this account.
	 *
	 * @param createDate the create date of this account
	 */
	public void setCreateDate(Date createDate);

	/**
	 * Gets the modified date of this account.
	 *
	 * @return the modified date of this account
	 */
	public Date getModifiedDate();

	/**
	 * Sets the modified date of this account.
	 *
	 * @param modifiedDate the modified date of this account
	 */
	public void setModifiedDate(Date modifiedDate);

	/**
	 * Gets the address of this account.
	 *
	 * @return the address of this account
	 */
	@AutoEscape
	public String getAddress();

	/**
	 * Sets the address of this account.
	 *
	 * @param address the address of this account
	 */
	public void setAddress(String address);

	/**
	 * Gets the personal name of this account.
	 *
	 * @return the personal name of this account
	 */
	@AutoEscape
	public String getPersonalName();

	/**
	 * Sets the personal name of this account.
	 *
	 * @param personalName the personal name of this account
	 */
	public void setPersonalName(String personalName);

	/**
	 * Gets the protocol of this account.
	 *
	 * @return the protocol of this account
	 */
	@AutoEscape
	public String getProtocol();

	/**
	 * Sets the protocol of this account.
	 *
	 * @param protocol the protocol of this account
	 */
	public void setProtocol(String protocol);

	/**
	 * Gets the incoming host name of this account.
	 *
	 * @return the incoming host name of this account
	 */
	@AutoEscape
	public String getIncomingHostName();

	/**
	 * Sets the incoming host name of this account.
	 *
	 * @param incomingHostName the incoming host name of this account
	 */
	public void setIncomingHostName(String incomingHostName);

	/**
	 * Gets the incoming port of this account.
	 *
	 * @return the incoming port of this account
	 */
	public int getIncomingPort();

	/**
	 * Sets the incoming port of this account.
	 *
	 * @param incomingPort the incoming port of this account
	 */
	public void setIncomingPort(int incomingPort);

	/**
	 * Gets the incoming secure of this account.
	 *
	 * @return the incoming secure of this account
	 */
	public boolean getIncomingSecure();

	/**
	 * Determines whether this account is incoming secure.
	 *
	 * @return whether this account is incoming secure
	 */
	public boolean isIncomingSecure();

	/**
	 * Sets the incoming secure of this account.
	 *
	 * @param incomingSecure the incoming secure of this account
	 */
	public void setIncomingSecure(boolean incomingSecure);

	/**
	 * Gets the outgoing host name of this account.
	 *
	 * @return the outgoing host name of this account
	 */
	@AutoEscape
	public String getOutgoingHostName();

	/**
	 * Sets the outgoing host name of this account.
	 *
	 * @param outgoingHostName the outgoing host name of this account
	 */
	public void setOutgoingHostName(String outgoingHostName);

	/**
	 * Gets the outgoing port of this account.
	 *
	 * @return the outgoing port of this account
	 */
	public int getOutgoingPort();

	/**
	 * Sets the outgoing port of this account.
	 *
	 * @param outgoingPort the outgoing port of this account
	 */
	public void setOutgoingPort(int outgoingPort);

	/**
	 * Gets the outgoing secure of this account.
	 *
	 * @return the outgoing secure of this account
	 */
	public boolean getOutgoingSecure();

	/**
	 * Determines whether this account is outgoing secure.
	 *
	 * @return whether this account is outgoing secure
	 */
	public boolean isOutgoingSecure();

	/**
	 * Sets the outgoing secure of this account.
	 *
	 * @param outgoingSecure the outgoing secure of this account
	 */
	public void setOutgoingSecure(boolean outgoingSecure);

	/**
	 * Gets the login of this account.
	 *
	 * @return the login of this account
	 */
	@AutoEscape
	public String getLogin();

	/**
	 * Sets the login of this account.
	 *
	 * @param login the login of this account
	 */
	public void setLogin(String login);

	/**
	 * Gets the password of this account.
	 *
	 * @return the password of this account
	 */
	@AutoEscape
	public String getPassword();

	/**
	 * Sets the password of this account.
	 *
	 * @param password the password of this account
	 */
	public void setPassword(String password);

	/**
	 * Gets the save password of this account.
	 *
	 * @return the save password of this account
	 */
	public boolean getSavePassword();

	/**
	 * Determines whether this account is save password.
	 *
	 * @return whether this account is save password
	 */
	public boolean isSavePassword();

	/**
	 * Sets the save password of this account.
	 *
	 * @param savePassword the save password of this account
	 */
	public void setSavePassword(boolean savePassword);

	/**
	 * Gets the signature of this account.
	 *
	 * @return the signature of this account
	 */
	@AutoEscape
	public String getSignature();

	/**
	 * Sets the signature of this account.
	 *
	 * @param signature the signature of this account
	 */
	public void setSignature(String signature);

	/**
	 * Gets the use signature of this account.
	 *
	 * @return the use signature of this account
	 */
	public boolean getUseSignature();

	/**
	 * Determines whether this account is use signature.
	 *
	 * @return whether this account is use signature
	 */
	public boolean isUseSignature();

	/**
	 * Sets the use signature of this account.
	 *
	 * @param useSignature the use signature of this account
	 */
	public void setUseSignature(boolean useSignature);

	/**
	 * Gets the folder prefix of this account.
	 *
	 * @return the folder prefix of this account
	 */
	@AutoEscape
	public String getFolderPrefix();

	/**
	 * Sets the folder prefix of this account.
	 *
	 * @param folderPrefix the folder prefix of this account
	 */
	public void setFolderPrefix(String folderPrefix);

	/**
	 * Gets the inbox folder id of this account.
	 *
	 * @return the inbox folder id of this account
	 */
	public long getInboxFolderId();

	/**
	 * Sets the inbox folder id of this account.
	 *
	 * @param inboxFolderId the inbox folder id of this account
	 */
	public void setInboxFolderId(long inboxFolderId);

	/**
	 * Gets the draft folder id of this account.
	 *
	 * @return the draft folder id of this account
	 */
	public long getDraftFolderId();

	/**
	 * Sets the draft folder id of this account.
	 *
	 * @param draftFolderId the draft folder id of this account
	 */
	public void setDraftFolderId(long draftFolderId);

	/**
	 * Gets the sent folder id of this account.
	 *
	 * @return the sent folder id of this account
	 */
	public long getSentFolderId();

	/**
	 * Sets the sent folder id of this account.
	 *
	 * @param sentFolderId the sent folder id of this account
	 */
	public void setSentFolderId(long sentFolderId);

	/**
	 * Gets the trash folder id of this account.
	 *
	 * @return the trash folder id of this account
	 */
	public long getTrashFolderId();

	/**
	 * Sets the trash folder id of this account.
	 *
	 * @param trashFolderId the trash folder id of this account
	 */
	public void setTrashFolderId(long trashFolderId);

	/**
	 * Gets the default sender of this account.
	 *
	 * @return the default sender of this account
	 */
	public boolean getDefaultSender();

	/**
	 * Determines whether this account is default sender.
	 *
	 * @return whether this account is default sender
	 */
	public boolean isDefaultSender();

	/**
	 * Sets the default sender of this account.
	 *
	 * @param defaultSender the default sender of this account
	 */
	public void setDefaultSender(boolean defaultSender);

	/**
	 * Gets a copy of this account as an escaped model instance by wrapping it with an {@link com.liferay.portal.kernel.bean.AutoEscapeBeanHandler}.
	 *
	 * @return the escaped model instance
	 * @see com.liferay.portal.kernel.bean.AutoEscapeBeanHandler
	 */
	public Account toEscapedModel();

	public boolean isNew();

	public void setNew(boolean n);

	public boolean isCachedModel();

	public void setCachedModel(boolean cachedModel);

	public boolean isEscapedModel();

	public void setEscapedModel(boolean escapedModel);

	public Serializable getPrimaryKeyObj();

	public ExpandoBridge getExpandoBridge();

	public void setExpandoBridgeAttributes(ServiceContext serviceContext);

	public Object clone();

	public int compareTo(Account account);

	public int hashCode();

	public String toString();

	public String toXmlString();
}