/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.mail.model;

import com.liferay.portal.kernel.annotation.AutoEscape;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.model.BaseModel;
import com.liferay.portal.service.ServiceContext;

import com.liferay.portlet.expando.model.ExpandoBridge;

import java.io.Serializable;

/**
 * The base model interface for the Attachment service. Represents a row in the &quot;Mail_Attachment&quot; database table, with each column mapped to a property of this class.
 *
 * <p>
 * This interface and its corresponding implementation {@link com.liferay.mail.model.impl.AttachmentModelImpl} exist only as a container for the default property accessors generated by ServiceBuilder. All helper methods and application logic should be put in {@link com.liferay.mail.model.impl.AttachmentImpl}.
 * </p>
 *
 * <p>
 * Never reference this interface directly. All methods that expect a attachment model instance should use the {@link Attachment} interface instead.
 * </p>
 *
 * @author    Brian Wing Shun Chan
 * @see       Attachment
 * @see       com.liferay.mail.model.impl.AttachmentImpl
 * @see       com.liferay.mail.model.impl.AttachmentModelImpl
 * @generated
 */
public interface AttachmentModel extends BaseModel<Attachment> {
	/**
	 * Gets the primary key of this attachment.
	 *
	 * @return the primary key of this attachment
	 */
	public long getPrimaryKey();

	/**
	 * Sets the primary key of this attachment
	 *
	 * @param pk the primary key of this attachment
	 */
	public void setPrimaryKey(long pk);

	/**
	 * Gets the attachment id of this attachment.
	 *
	 * @return the attachment id of this attachment
	 */
	public long getAttachmentId();

	/**
	 * Sets the attachment id of this attachment.
	 *
	 * @param attachmentId the attachment id of this attachment
	 */
	public void setAttachmentId(long attachmentId);

	/**
	 * Gets the company id of this attachment.
	 *
	 * @return the company id of this attachment
	 */
	public long getCompanyId();

	/**
	 * Sets the company id of this attachment.
	 *
	 * @param companyId the company id of this attachment
	 */
	public void setCompanyId(long companyId);

	/**
	 * Gets the user id of this attachment.
	 *
	 * @return the user id of this attachment
	 */
	public long getUserId();

	/**
	 * Sets the user id of this attachment.
	 *
	 * @param userId the user id of this attachment
	 */
	public void setUserId(long userId);

	/**
	 * Gets the user uuid of this attachment.
	 *
	 * @return the user uuid of this attachment
	 * @throws SystemException if a system exception occurred
	 */
	public String getUserUuid() throws SystemException;

	/**
	 * Sets the user uuid of this attachment.
	 *
	 * @param userUuid the user uuid of this attachment
	 */
	public void setUserUuid(String userUuid);

	/**
	 * Gets the account id of this attachment.
	 *
	 * @return the account id of this attachment
	 */
	public long getAccountId();

	/**
	 * Sets the account id of this attachment.
	 *
	 * @param accountId the account id of this attachment
	 */
	public void setAccountId(long accountId);

	/**
	 * Gets the folder id of this attachment.
	 *
	 * @return the folder id of this attachment
	 */
	public long getFolderId();

	/**
	 * Sets the folder id of this attachment.
	 *
	 * @param folderId the folder id of this attachment
	 */
	public void setFolderId(long folderId);

	/**
	 * Gets the message id of this attachment.
	 *
	 * @return the message id of this attachment
	 */
	public long getMessageId();

	/**
	 * Sets the message id of this attachment.
	 *
	 * @param messageId the message id of this attachment
	 */
	public void setMessageId(long messageId);

	/**
	 * Gets the content path of this attachment.
	 *
	 * @return the content path of this attachment
	 */
	@AutoEscape
	public String getContentPath();

	/**
	 * Sets the content path of this attachment.
	 *
	 * @param contentPath the content path of this attachment
	 */
	public void setContentPath(String contentPath);

	/**
	 * Gets the file name of this attachment.
	 *
	 * @return the file name of this attachment
	 */
	@AutoEscape
	public String getFileName();

	/**
	 * Sets the file name of this attachment.
	 *
	 * @param fileName the file name of this attachment
	 */
	public void setFileName(String fileName);

	/**
	 * Gets the size of this attachment.
	 *
	 * @return the size of this attachment
	 */
	public long getSize();

	/**
	 * Sets the size of this attachment.
	 *
	 * @param size the size of this attachment
	 */
	public void setSize(long size);

	/**
	 * Gets a copy of this attachment as an escaped model instance by wrapping it with an {@link com.liferay.portal.kernel.bean.AutoEscapeBeanHandler}.
	 *
	 * @return the escaped model instance
	 * @see com.liferay.portal.kernel.bean.AutoEscapeBeanHandler
	 */
	public Attachment toEscapedModel();

	public boolean isNew();

	public void setNew(boolean n);

	public boolean isCachedModel();

	public void setCachedModel(boolean cachedModel);

	public boolean isEscapedModel();

	public void setEscapedModel(boolean escapedModel);

	public Serializable getPrimaryKeyObj();

	public ExpandoBridge getExpandoBridge();

	public void setExpandoBridgeAttributes(ServiceContext serviceContext);

	public Object clone();

	public int compareTo(Attachment attachment);

	public int hashCode();

	public String toString();

	public String toXmlString();
}